@@ -71,6 +71,7 @@ The default value of $eps is 1e-8. Don't try sending anything to the Moon with t
 
 sub is_similar {
     my ($x,$y, $eps, $similarity_function) = @_;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
     $eps ||= 1e-8;
     if (ref $x eq 'ARRAY' && ref $y eq 'ARRAY') {
         if ( $#$x != $#$y ){
@@ -104,8 +105,8 @@ sub is_similar {
 sub verify_results
 {
     my ($results,$class) = @_;
-    # GSL uses a factor of 100 
-    my $factor   = 20; 
+    # GSL uses a factor of 100
+    my $factor   = 100;
     my $eps      = 2048*$Math::GSL::Machine::GSL_DBL_EPSILON; # TOL3
     my ($x,$res);
     local $Test::Builder::Level = $Test::Builder::Level + 1;
@@ -119,7 +120,9 @@ sub verify_results
         
         if ( defined $r && $code =~ /_e\(.*\$r/) {
             $x   = $r->{val};
-            $eps = $factor*$r->{err};
+
+            # if $eps=0, give some default
+            $eps = $factor*$r->{err} || 1e-8;
             $res = abs($x-$expected);
 
             if ($ENV{DEBUG} ){
@@ -130,11 +133,11 @@ sub verify_results
                 printf "unexpected error of %.18g\n", $res-$eps if ($res-$eps>0);
             }
             if (gsl_isnan($x)) {
-                    ok( gsl_isnan($expected), "'$expected'?='$x'" );
+                    ok( gsl_isnan($expected), sprintf("'$expected'?='$x' (%16b ?= %16b)", $expected, $x) );
             } elsif(gsl_isinf($x)) { 
-                    ok( gsl_isinf($expected), "'$expected'?='$x'" );
+                    ok( gsl_isinf($expected), sprintf("'$expected'?='$x' (%16b ?= %16b)", $expected, $x) );
             } else {
-                ok( $res <= $eps, "$code ?= $x,\nres= +-$res, eps=$eps" );    
+                    cmp_ok( $res,'<=', $eps, "$code ?= $x,\nres= +-$res, eps=$eps" );
             }
         }
     }
@@ -200,10 +203,9 @@ sub ok_status {
     my ($got, $expected, $msg ) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
     $expected ||= $GSL_SUCCESS;
-    my $strerr = gsl_strerror(int($got));
-    $msg       = $msg ? "$msg: " . $strerr : $strerr;
+    my $strerr = $got ? gsl_strerror(int($got)) : '';
 
-    ok( defined $got && $got == $expected, $msg );
+    ok( defined $got && $got == $expected, $msg ? "$msg: " .$strerr : $strerr );
 }
 
 =head2 is_status_ok($status)
